---
title: <span class="badge object-type-scalar"></span> YottaFlopsPerSecond
---
# <span class="badge object-type-scalar"></span> YottaFlopsPerSecond

Computation: YFLOP/s

## Definition

```python
# Computation: YFLOP/s
YottaFlopsPerSecond: typing.Literal["yflops"] = "yflops"
```
